==> jsmex-trader-sdk-1.1.32.tgz: package/lib/data/OrderDTO.js <==
const IDTO = global.IDTO || require('./IDTO')
const Joi = global.Joi || require('../../static_dependencies/joi/joi-browser.min.js')
const UID = global.UID || require('../utils/UID')
/**
 * OrderDTO class
 *
 * @author jsb4ch <jsb4ch@jsmex.io>
 * @since 1.0.0
*/
class OrderDTO extends IDTO {
  constructor (uid) {
    super(uid)

    this.symbolId = ''
    this.orderId = null
    this.time = null
    this.type = ''
    this.side = ''
    this.price = ''
    this.trigger = ''
    this.value = ''
    this.left = ''
    this.label = ''
  }

  /**
   * OrderDTO get symbol
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.69
  */
  get symbol () {
    return this.symbolId
  }

  /**
   * OrderDTO set symbol
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.69
  */
  set symbol (symbolId) {
    this.symbolId = symbolId
  }

  /**
   * OrderDTO validation method
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.0
  */
  validate ({ strict = true } = {}) {
    let data = {
      symbolId: this.symbolId,
      orderId: this.orderId,
      time: this.time,
      type: this.type,
      side: this.side,
      price: this.price,
      trigger: this.trigger,
      value: this.value,
      left: this.left,
      label: this.label
    }
    if (!strict) {
      return true
    }
    let joiValidDepth = Joi.object()
      .keys({
        symbolId: Joi.alternatives().try(Joi.string(), Joi.string().valid('')).required(),
        orderId: Joi.number().required(),
        time: Joi.number().required(),
        type: Joi.string().alphanum().min(3).max(50).required(),
        side: Joi.alternatives().try(
          Joi.string().valid('ask', 'bid', '1', '2'),
          Joi.number().valid(1, 2)
        ),
        price: Joi.string().regex(/^\d+\.\d+$|^\d+$/).min(1).max(50).required(),
        value: Joi.string().regex(/^\d+\.\d+$|^\d+$/).min(1).max(50).required(),
        left: Joi.alternatives().try(
          Joi.string().regex(/^\d+\.\d+$|^\d+$/).min(1).max(50),
          Joi.string().valid('', '0e-8', '0e-16', '0e-20')
        ),
        trigger: Joi.alternatives().try(
          Joi.string().regex(/^\d+\.\d+$|^\d+$/).min(1).max(50),
          Joi.string().valid('')
        ),
        label: Joi.alternatives().try(
          Joi.string(),
          Joi.string().valid('')
        )
      })

    let result = Joi.validate(data, joiValidDepth)
    if (result.error) {
      throw result.error
    }
    return result.value
  }

  /**
   * OrderDTO toObject method
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.14
   * @returns {Object}
  */
  toObject () {
    return {
      uid: this.uid,
      symbol: this.symbolId,
      symbolId: this.symbolId,
      time: this.time,
      orderId: this.orderId,
      type: this.type,
      side: this.side,
      price: this.price,
      trigger: this.trigger,
      value: this.value,
      left: this.left,
      label: this.label
    }
  }

  /**
   * OrderDTO fromObject method
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.14
   * @param objectData object
   * @returns OrderDTO
  */
  static fromObject (objectData) {
    let orderDTO = new OrderDTO(UID.create())
    orderDTO.symbolId = objectData.symbolId
    orderDTO.orderId = objectData.orderId
    orderDTO.time = objectData.time
    orderDTO.type = objectData.type
    orderDTO.side = objectData.side
    orderDTO.price = objectData.price
    orderDTO.trigger = objectData.trigger
    orderDTO.value = objectData.value
    orderDTO.left = objectData.left
    orderDTO.label = objectData.label
    orderDTO.validate()
    return orderDTO
  }
}

module.exports = OrderDTO

==> jsmex-trader-sdk-1.1.50.tgz: package/lib/data/OrderDTO.js <==
const IDTO = global.IDTO || require('./IDTO')
const Joi = global.Joi || require('../../static_dependencies/joi/joi-browser.min.js')
const UID = global.UID || require('../utils/UID')
/**
 * OrderDTO class
 *
 * @author jsb4ch <jsb4ch@jsmex.io>
 * @since 1.0.0
*/
class OrderDTO extends IDTO {
  constructor (uid) {
    super(uid)

    this.symbolId = ''
    this.orderId = null
    this.time = null
    this.type = ''
    this.side = ''
    this.price = ''
    this.trigger = ''
    this.value = ''
    this.left = ''
    this.label = ''
  }

  /**
   * OrderDTO get symbol
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.69
  */
  get symbol () {
    return this.symbolId
  }

  /**
   * OrderDTO set symbol
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.69
  */
  set symbol (symbolId) {
    this.symbolId = symbolId
  }

  /**
   * OrderDTO validation method
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.0
  */
  validate ({ strict = true } = {}) {
    let data = {
      symbolId: this.symbolId,
      orderId: this.orderId,
      time: this.time,
      type: this.type,
      side: this.side,
      price: this.price,
      trigger: this.trigger,
      value: this.value,
      left: this.left,
      label: this.label
    }
    if (!strict) {
      return true
    }
    let joiValidDepth = Joi.object()
      .keys({
        symbolId: Joi.alternatives().try(Joi.string(), Joi.string().valid('')).required(),
        orderId: Joi.number().required(),
        time: Joi.number().required(),
        type: Joi.string().alphanum().min(3).max(50).required(),
        side: Joi.alternatives().try(
          Joi.string().valid('ask', 'bid', '1', '2'),
          Joi.number().valid(1, 2)
        ),
        price: Joi.string().regex(/^\d+\.\d+$|^\d+\.\d+e-\d+$|^\d+$|^\d+e-\d+$/).min(1).max(50).required(),
        value: Joi.string().regex(/^\d+\.\d+$|^\d+\.\d+e-\d+$|^\d+$|^\d+e-\d+$/).min(1).max(50).required(),
        left: Joi.alternatives().try(
          Joi.string().regex(/^\d+\.\d+$|^\d+\.\d+e-\d+$|^\d+$|^\d+e-\d+$/).min(1).max(50),
          Joi.string().valid('', '0e-8', '0e-16', '0e-20')
        ),
        trigger: Joi.alternatives().try(
          Joi.string().regex(/^\d+\.\d+$|^\d+\.\d+e-\d+$|^\d+$|^\d+e-\d+$/).min(1).max(50),
          Joi.string().valid('')
        ),
        label: Joi.alternatives().try(
          Joi.string(),
          Joi.string().valid('')
        )
      })

    let result = Joi.validate(data, joiValidDepth)
    if (result.error) {
      throw result.error
    }
    return result.value
  }

  /**
   * OrderDTO toObject method
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.14
   * @returns {Object}
  */
  toObject () {
    return {
      uid: this.uid,
      symbol: this.symbolId,
      symbolId: this.symbolId,
      time: this.time,
      orderId: this.orderId,
      type: this.type,
      side: this.side,
      price: this.price,
      trigger: this.trigger,
      value: this.value,
      left: this.left,
      label: this.label
    }
  }

  /**
   * OrderDTO fromObject method
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.14
   * @param objectData object
   * @returns OrderDTO
  */
  static fromObject (objectData) {
    let orderDTO = new OrderDTO(UID.create())
    orderDTO.symbolId = objectData.symbolId
    orderDTO.orderId = objectData.orderId
    orderDTO.time = objectData.time
    orderDTO.type = objectData.type
    orderDTO.side = objectData.side
    orderDTO.price = objectData.price
    orderDTO.trigger = objectData.trigger
    orderDTO.value = objectData.value
    orderDTO.left = objectData.left
    orderDTO.label = objectData.label
    orderDTO.validate()
    return orderDTO
  }
}

module.exports = OrderDTO
